import axios from "axios";
import { getToken, removeToken } from "@/utils/auth";
import router from "@/router";
import { Toast } from "vant";
const baseURL = process.env.NODE_ENV === "production" ? "/api" : "/proxyApi";
const request = axios.create({
  baseURL,
  timeout: 10000,
  withCredentials: true,
});
request.interceptors.request.use(
  (config) => {
    config.headers["Authorization"] = "Bearer " + getToken();
    return config;
  },
  (error) => {
    return Promise.reject(error);
  }
);
request.interceptors.response.use(
  (response) => {
    const res = response.data;
    if (res.code === 200) {
      return res;
    } else if (res.code === 401) {
      Toast.fail(res.msg);
      removeToken();
      router.push("/");
    } else {
      Toast.fail(res.msg);
      return res;
    }
  },
  (err) => {
    Toast("网络请求异常，请稍后重试!");
    return err;
  }
);
export default request;
